import { Vue, Component } from 'vue-property-decorator';
import { AppService } from '@/studio-core/service/app-service/AppService';
import './app-breadcrumb.less';

/**
 * 面包屑导航组件
 *
 * @export
 * @class AppBreadcrumb
 * @extends {Vue}
 */
@Component({})
export class AppBreadcrumb extends Vue {

    /**
     * 应用服务(单例)
     *
     * @protected
     * @type {AppService}
     * @memberof AppHeader
     */
    protected appService: AppService = new AppService();

    /**
     * 跳转点击
     *
     * @protected
     * @param {*} to
     * @memberof AppBreadcrumb
     */
    protected click(to: any) {
        const i = this.$appService.navHistory.findHistoryIndex(to);
        this.$router.push({ path: to.path, params: to.params, query: to.query });
        this.$appService.navHistory.reset(i + 1);
    }

    /**
     * 跳转首页
     *
     * @protected
     * @param {*} meta
     * @memberof AppBreadcrumb
     */
    protected toIndex(meta: any): void {
        let path = '';
        if (meta && meta.parameters) {
            meta.parameters.forEach((item: any) => {
                const val = this.$route.params[item.parameterName];
                path += `/${item.pathName}${val ? `/${val}` : ''}`;
            });
        }
        this.$router.push(path);
        this.$appService.navHistory.reset();
        location.reload();
    }

    /**
     * 绘制面包屑
     *
     * @returns {*}
     * @memberof AppBreadcrumb
     */
    public render(): any {
        const items: any[] = [];
        const indexMeta = this.appService.navHistory.indexMeta;
        if (indexMeta) {
            items.push(<span class="app-breadcrumb-item">
                <span class="content" on-click={() => this.toIndex(indexMeta)}>首页</span>
            </span>);
        }
        const arr = this.appService.navHistory.historyList;
        arr.forEach((item, i) => {
            items.push(<span class={{ 'app-breadcrumb-item': true, 'last': i === (arr.length - 1) }}>
                {(!indexMeta && i === 0) ? null : <span class="separator">/</span>}
                <span class="content" on-click={() => this.click(item.to)}>{this.$t(item.meta?.caption)}{(item.meta?.info && item.meta?.info !== '') ? ` - ${item.meta?.info}` : ''}</span>
            </span>);
        });
        return <div class="app-breadcrumb">{items}</div>;
    }
}